summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qmenuitem_imp.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/qtbindings/qmenuitem_imp.h
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/qtbindings/qmenuitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qmenuitem_imp.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kjsembed/qtbindings/qmenuitem_imp.h b/kjsembed/qtbindings/qmenuitem_imp.h
index 59b7d996..ad1e480b 100644
--- a/kjsembed/qtbindings/qmenuitem_imp.h
+++ b/kjsembed/qtbindings/qmenuitem_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQMenuItem;
+class TTQMenuItem;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQMenuItem;
namespace KJSEmbed {
/**
* Wrapper class for TQMenuItem methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QMenuItemImp : public JSProxyImp
+class TQMenuItemImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -57,8 +57,8 @@ public:
Method_Last = -1
};
- QMenuItemImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QMenuItemImp();
+ TQMenuItemImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQMenuItemImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -72,13 +72,13 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQMenuItem *toQMenuItem( KJS::Object &object );
+ static TTQMenuItem *toTQMenuItem( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QMenuItem_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQMenuItem_1( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -122,7 +122,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQMenuItem *instance; // Temp
+ TTQMenuItem *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQMenuItem;
namespace KJSEmbed {
/**
- * Wrapper class for TQMenuItem methods.
+ * Wrapper class for TTQMenuItem methods.
*
* @author Richard Moore, rich@kde.org